package com.sun.java.swing.plaf.motif;

import java.awt.Component;
import javax.swing.SwingUtilities;
import java.awt.Container;
import javax.swing.KeyStroke;
import java.awt.Font;
import java.awt.Insets;
import java.awt.Dimension;
import javax.swing.ButtonModel;
import javax.swing.JMenuBar;
import javax.swing.text.View;
import java.awt.event.KeyEvent;
import javax.swing.JMenu;
import javax.swing.UIManager;
import java.awt.Rectangle;
import javax.swing.JMenuItem;
import javax.swing.Icon;
import java.awt.FontMetrics;
import sun.swing.SwingUtilities2;
import javax.swing.JComponent;
import java.awt.Color;
import java.awt.Graphics;
import javax.swing.SwingConstants;

public class MotifGraphicsUtils implements SwingConstants
{
    private static final String MAX_ACC_WIDTH = "maxAccWidth";
    
    public MotifGraphicsUtils() {
    }
    
    static void drawPoint(Graphics graphics, int n, int n2) {
        graphics.drawLine(n, n2, n, n2);
    }
    
    public static void drawGroove(Graphics graphics, int n, int n2, int n3, int n4, Color color, Color color2) {
        Color color3 = graphics.getColor();
        graphics.translate(n, n2);
        graphics.setColor(color);
        graphics.drawRect(0, 0, n3 - 2, n4 - 2);
        graphics.setColor(color2);
        graphics.drawLine(1, n4 - 3, 1, 1);
        graphics.drawLine(1, 1, n3 - 3, 1);
        graphics.drawLine(0, n4 - 1, n3 - 1, n4 - 1);
        graphics.drawLine(n3 - 1, n4 - 1, n3 - 1, 0);
        graphics.translate(-n, -n2);
        graphics.setColor(color3);
    }
    
    public static void drawStringInRect(Graphics graphics, String s, int n, int n2, int n3, int n4, int n5) {
        drawStringInRect(null, graphics, s, n, n2, n3, n4, n5);
    }
    
    static void drawStringInRect(JComponent component, Graphics graphics, String text, int n, int n2, int n3, int n4, int n5) {
        if (graphics.getFont() == null) {
            return;
        }
        FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(component, graphics);
        if (fontMetrics == null) {
            return;
        }
        int x;
        if (n5 == 0) {
            int stringWidth2 = SwingUtilities2.stringWidth(component, fontMetrics, text);
            if (stringWidth2 > n3) {
                stringWidth2 = n3;
            }
            x = n + (n3 - stringWidth2) / 2;
        }
        else if (n5 == 4) {
            int stringWidth = SwingUtilities2.stringWidth(component, fontMetrics, text);
            if (stringWidth > n3) {
                stringWidth = n3;
            }
            x = n + n3 - stringWidth;
        }
        else {
            x = n;
        }
        int n6 = (n4 - fontMetrics.getAscent() - fontMetrics.getDescent()) / 2;
        if (n6 < 0) {
            n6 = 0;
        }
        SwingUtilities2.drawString(component, graphics, text, x, n2 + n4 - n6 - fontMetrics.getDescent());
        return;
    }
    
    public static void paintMenuItem(Graphics graphics, JComponent c, Icon icon, Icon icon2, Color color, Color color2, int n) {
        JMenuItem c2 = (JMenuItem)c;
        ButtonModel model = c2.getModel();
        Dimension size = c2.getSize();
        Insets insets = c.getInsets();
        Rectangle rectangle = new Rectangle(size);
        rectangle.x += insets.left;
        rectangle.y += insets.top;
        rectangle.width -= insets.right + rectangle.x;
        rectangle.height -= insets.bottom + rectangle.y;
        Rectangle rectangle2 = new Rectangle();
        Rectangle rectangle3 = new Rectangle();
        Rectangle rectangle4 = new Rectangle();
        Rectangle rectangle5 = new Rectangle();
        Rectangle rectangle6 = new Rectangle();
        Font font = graphics.getFont();
        Font font2 = c.getFont();
        graphics.setFont(font2);
        FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(c, graphics, font2);
        FontMetrics fontMetrics2 = SwingUtilities2.getFontMetrics(c, graphics, UIManager.getFont("MenuItem.acceleratorFont"));
        if (c.isOpaque()) {
            if (model.isArmed() || (c instanceof JMenu && model.isSelected())) {
                graphics.setColor(color);
            }
            else {
                graphics.setColor(c.getBackground());
            }
            graphics.fillRect(0, 0, size.width, size.height);
        }
        KeyStroke accelerator = c2.getAccelerator();
        String s = "";
        if (accelerator != null) {
            int modifiers = accelerator.getModifiers();
            if (modifiers > 0) {
                s = KeyEvent.getKeyModifiersText(modifiers) + "+";
            }
            s += KeyEvent.getKeyText(accelerator.getKeyCode());
        }
        String layoutMenuItem = layoutMenuItem(c, fontMetrics, c2.getText(), fontMetrics2, s, c2.getIcon(), icon, icon2, c2.getVerticalAlignment(), c2.getHorizontalAlignment(), c2.getVerticalTextPosition(), c2.getHorizontalTextPosition(), rectangle, rectangle2, rectangle3, rectangle4, rectangle5, rectangle6, (c2.getText() == null) ? 0 : n, n);
        Color color3 = graphics.getColor();
        if (icon != null) {
            if (model.isArmed() || (c instanceof JMenu && model.isSelected())) {
                graphics.setColor(color2);
            }
            icon.paintIcon(c, graphics, rectangle5.x, rectangle5.y);
            graphics.setColor(color3);
        }
        if (c2.getIcon() != null) {
            Icon icon3;
            if (!model.isEnabled()) {
                icon3 = c2.getDisabledIcon();
            }
            else if (model.isPressed() && model.isArmed()) {
                icon3 = c2.getPressedIcon();
                if (icon3 == null) {
                    icon3 = c2.getIcon();
                }
            }
            else {
                icon3 = c2.getIcon();
            }
            if (icon3 != null) {
                icon3.paintIcon(c, graphics, rectangle2.x, rectangle2.y);
            }
        }
        if (layoutMenuItem != null && !layoutMenuItem.equals("")) {
            View view = (View)c.getClientProperty("html");
            if (view != null) {
                view.paint(graphics, rectangle3);
            }
            else {
                int displayedMnemonicIndex = c2.getDisplayedMnemonicIndex();
                if (!model.isEnabled()) {
                    graphics.setColor(c2.getBackground().brighter());
                    SwingUtilities2.drawStringUnderlineCharAt(c2, graphics, layoutMenuItem, displayedMnemonicIndex, rectangle3.x, rectangle3.y + fontMetrics2.getAscent());
                    graphics.setColor(c2.getBackground().darker());
                    SwingUtilities2.drawStringUnderlineCharAt(c2, graphics, layoutMenuItem, displayedMnemonicIndex, rectangle3.x - 1, rectangle3.y + fontMetrics2.getAscent() - 1);
                }
                else {
                    if (model.isArmed() || (c instanceof JMenu && model.isSelected())) {
                        graphics.setColor(color2);
                    }
                    else {
                        graphics.setColor(c2.getForeground());
                    }
                    SwingUtilities2.drawStringUnderlineCharAt(c2, graphics, layoutMenuItem, displayedMnemonicIndex, rectangle3.x, rectangle3.y + fontMetrics.getAscent());
                }
            }
        }
        if (s != null && !s.equals("")) {
            int n2 = 0;
            Container parent = c2.getParent();
            if (parent != null && parent instanceof JComponent) {
                Integer n3 = (Integer)((JComponent)parent).getClientProperty("maxAccWidth");
                n2 = ((n3 != null) ? ((int)n3) : rectangle4.width) - rectangle4.width;
            }
            graphics.setFont(UIManager.getFont("MenuItem.acceleratorFont"));
            if (!model.isEnabled()) {
                graphics.setColor(c2.getBackground().brighter());
                SwingUtilities2.drawString(c, graphics, s, rectangle4.x - n2, rectangle4.y + fontMetrics.getAscent());
                graphics.setColor(c2.getBackground().darker());
                SwingUtilities2.drawString(c, graphics, s, rectangle4.x - n2 - 1, rectangle4.y + fontMetrics.getAscent() - 1);
            }
            else {
                if (model.isArmed() || (c instanceof JMenu && model.isSelected())) {
                    graphics.setColor(color2);
                }
                else {
                    graphics.setColor(c2.getForeground());
                }
                SwingUtilities2.drawString(c, graphics, s, rectangle4.x - n2, rectangle4.y + fontMetrics2.getAscent());
            }
        }
        if (icon2 != null) {
            if (model.isArmed() || (c instanceof JMenu && model.isSelected())) {
                graphics.setColor(color2);
            }
            if (!(c2.getParent() instanceof JMenuBar)) {
                icon2.paintIcon(c, graphics, rectangle6.x, rectangle6.y);
            }
        }
        graphics.setColor(color3);
        graphics.setFont(font);
    }
    
    private static String layoutMenuItem(JComponent component, FontMetrics fm, String text, FontMetrics fm2, String string, Icon icon, Icon icon2, Icon icon3, int verticalAlignment, int horizontalAlignment, int verticalTextPosition, int horizontalTextPosition, Rectangle viewR, Rectangle iconR, Rectangle rectangle, Rectangle rectangle2, Rectangle rectangle3, Rectangle rectangle4, int textIconGap, int n) {
        SwingUtilities.layoutCompoundLabel(component, fm, text, icon, verticalAlignment, horizontalAlignment, verticalTextPosition, horizontalTextPosition, viewR, iconR, rectangle, textIconGap);
        if (string == null || string.equals("")) {
            int n2 = 0;
            rectangle2.height = n2;
            rectangle2.width = n2;
            string = "";
        }
        else {
            rectangle2.width = SwingUtilities2.stringWidth(component, fm2, string);
            rectangle2.height = fm2.getHeight();
        }
        if (icon2 != null) {
            rectangle3.width = icon2.getIconWidth();
            rectangle3.height = icon2.getIconHeight();
        }
        else {
            int n3 = 0;
            rectangle3.height = n3;
            rectangle3.width = n3;
        }
        if (icon3 != null) {
            rectangle4.width = icon3.getIconWidth();
            rectangle4.height = icon3.getIconHeight();
        }
        else {
            int n4 = 0;
            rectangle4.height = n4;
            rectangle4.width = n4;
        }
        Rectangle union = iconR.union(rectangle);
        if (isLeftToRight(component)) {
            rectangle.x += rectangle3.width + n;
            iconR.x += rectangle3.width + n;
            rectangle2.x = viewR.x + viewR.width - rectangle4.width - n - rectangle2.width;
            rectangle3.x = viewR.x;
            rectangle4.x = viewR.x + viewR.width - n - rectangle4.width;
        }
        else {
            rectangle.x -= rectangle3.width + n;
            iconR.x -= rectangle3.width + n;
            rectangle2.x = viewR.x + rectangle4.width + n;
            rectangle3.x = viewR.x + viewR.width - rectangle3.width;
            rectangle4.x = viewR.x + n;
        }
        rectangle2.y = union.y + union.height / 2 - rectangle2.height / 2;
        rectangle4.y = union.y + union.height / 2 - rectangle4.height / 2;
        rectangle3.y = union.y + union.height / 2 - rectangle3.height / 2;
        return text;
    }
    
    private static void drawMenuBezel(Graphics graphics, Color color, int n, int n2, int n3, int n4) {
        graphics.setColor(color);
        graphics.fillRect(n, n2, n3, n4);
        graphics.setColor(color.brighter().brighter());
        graphics.drawLine(n + 1, n2 + n4 - 1, n + n3 - 1, n2 + n4 - 1);
        graphics.drawLine(n + n3 - 1, n2 + n4 - 2, n + n3 - 1, n2 + 1);
        graphics.setColor(color.darker().darker());
        graphics.drawLine(n, n2, n + n3 - 2, n2);
        graphics.drawLine(n, n2 + 1, n, n2 + n4 - 2);
    }
    
    static boolean isLeftToRight(Component component) {
        return component.getComponentOrientation().isLeftToRight();
    }
}
